@@ -1,10 +1,14 @@
 #' Gather an `rset` Object
 #'
+#' @description
+#' `r lifecycle::badge("deprecated")`
+#'
 #' This method uses `gather` on an `rset` object to stack all of
 #'  the non-ID or split columns in the data and is useful for
 #'  stacking model evaluation statistics. The resulting data frame
 #'  has a column based on the column names of `data` and another for
-#'  the values.
+#'  the values. This method is now deprecated in favor of using
+#'  [tidyr::pivot_longer()] directly.
 #'
 #' @param data An `rset` object.
 #' @param key,value,... Not specified in this method and will be
@@ -26,13 +30,26 @@
 #' cv_obj <- vfold_cv(mtcars, v = 10)
 #' cv_obj$lm_rmse <- rnorm(10, mean = 2)
 #' cv_obj$nnet_rmse <- rnorm(10, mean = 1)
+#'
+#' ## now deprecated for rset objects:
 #' gather(cv_obj)
-#' @exportMethod gather.rset
+#'
+#' ## instead of gather, use tidyr::pivot_longer:
+#' library(tidyr)
+#' library(dplyr)
+#' cv_obj %>%
+#'   select(-splits) %>%
+#'   pivot_longer(-id)
+#'
 #' @export gather.rset
 #' @export
+#' @keywords internal
 #' @method gather rset
 gather.rset <- function(data, key = NULL, value = NULL, ..., na.rm = TRUE,
                         convert = FALSE, factor_key = TRUE) {
+
+  lifecycle::deprecate_warn("0.1.0", "gather.rset()", "tidyr::pivot_longer()")
+
   if (any(names(data) == "splits")) {
     data <- data %>% dplyr::select(-splits)
   }
